Developers
----------

* Mika Pflüger `<mika.pflueger@climate-resource.com>`_

Contributors
------------

* Florian Dierickx `<floriandierickx.github.io>`_
* Daniel Huppmann `<https://twitter.com/daniel_huppmann>`_
* Johannes Gütschow <johannes.guetschow@climate-resource.com>
